You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@libcloud.apache.org by qu...@apache.org on 2018/03/02 05:42:33 UTC

[06/13] libcloud git commit: docstr location and ex_only_active OS list_images

docstr location and ex_only_active OS list_images

Signed-off-by: Quentin Pradet <qu...@apache.org>


Project: http://git-wip-us.apache.org/repos/asf/libcloud/repo
Commit: http://git-wip-us.apache.org/repos/asf/libcloud/commit/8f12b92e
Tree: http://git-wip-us.apache.org/repos/asf/libcloud/tree/8f12b92e
Diff: http://git-wip-us.apache.org/repos/asf/libcloud/diff/8f12b92e

Branch: refs/heads/trunk
Commit: 8f12b92ebd1bf0395d169fb02773f6c6bedb09fe
Parents: eedcf77
Author: Rick van de Loo <ri...@gmail.com>
Authored: Sat Feb 10 18:13:10 2018 +0100
Committer: Quentin Pradet <qu...@apache.org>
Committed: Fri Mar 2 09:34:26 2018 +0400

----------------------------------------------------------------------
 libcloud/compute/drivers/openstack.py | 12 +++++++++++-
 1 file changed, 11 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/libcloud/blob/8f12b92e/libcloud/compute/drivers/openstack.py
----------------------------------------------------------------------
diff --git a/libcloud/compute/drivers/openstack.py b/libcloud/compute/drivers/openstack.py
index 9bd3881..3dfa47a 100644
--- a/libcloud/compute/drivers/openstack.py
+++ b/libcloud/compute/drivers/openstack.py
@@ -281,7 +281,7 @@ class OpenStackNodeDriver(NodeDriver, OpenStackDriverMixin):
 
         @inherits: :class:`NodeDriver.list_images`
 
         :param ex_only_active: True if list only active
         :type ex_only_active: ``bool``
 
         """
@@ -2537,6 +2537,16 @@ class OpenStack_2_NodeDriver(OpenStack_1_1_NodeDriver):
         Lists all active images using the V2 Glance API
 
         @inherits: :class:`NodeDriver.list_images`
+
+        :param location: Which data center to list the images in. If
+                               empty, undefined behavior will be selected.
+                               (optional)
+
+        :type location: :class:`.NodeLocation`
+        :param ex_only_active: True if list only active (optional)
+
+        :type ex_only_active: ``bool``
+
         """
         if location is not None:
             raise NotImplementedError(
@@ -281,7 +281,7 @@ class OpenStackNodeDriver(NodeDriver, OpenStackDriverMixin):
         @inherits: :class:`NodeDriver.list_images`
 
-        :param ex_only_active: True if list only active
+        :param ex_only_active: True if list only active (optional)
         :type ex_only_active: ``bool``
 